@@ -109,11 +109,11 @@ class EmailForwarders extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\Re
 
 	/**
 	 * You cannot directly get an email forwarder.
-	 * You need to call Emails.get()
+	 * Try EmailForwarders.listing()
 	 */
 	public function get()
 	{
-		throw new \Exception('You cannot directly get an email forwarder. You need to call Emails.get()', 303);
+		throw new \Exception('You cannot directly get an email forwarder. Try EmailForwarders.listing()', 303);
 	}
 
 	/**
@@ -126,12 +126,91 @@ class EmailForwarders extends \Froxlor\Api\ApiCommand implements \Froxlor\Api\Re
 	}
 
 	/**
-	 * You cannot directly list email forwarders.
-	 * You need to call Emails.listing()
+	 * List email forwarders for a given email address
+	 *
+	 * @param int $id
+	 *        	optional, the email-address-id
+	 * @param string $emailaddr
+	 *        	optional, the email-address to delete the forwarder from
+	 * @param int $customerid
+	 *        	optional, admin-only, the customer-id
+	 * @param string $loginname
+	 *        	optional, admin-only, the loginname
+	 *        	
+	 * @access admin,customer
+	 * @throws \Exception
+	 * @return string json-encoded array count|list
 	 */
 	public function listing()
 	{
-		throw new \Exception('You cannot directly list email forwarders. You need to call Emails.listing()', 303);
+		if ($this->isAdmin() == false && Settings::IsInList('panel.customer_hide_options', 'email')) {
+			throw new \Exception("You cannot access this resource", 405);
+		}
+
+		// parameter
+		$id = $this->getParam('id', true, 0);
+		$ea_optional = ($id <= 0 ? false : true);
+		$emailaddr = $this->getParam('emailaddr', $ea_optional, '');
+
+		// validation
+		$result = $this->apiCall('Emails.get', array(
+			'id' => $id,
+			'emailaddr' => $emailaddr
+		));
+		$id = $result['id'];
+
+		$result['destination'] = explode(' ', $result['destination']);
+		$destination = array();
+		foreach ($result['destination'] as $index => $address) {
+			$destination[] = [
+				'id' => $index,
+				'address' => $address
+			];
+		}
+
+		return $this->response(200, "successfull", [
+			'count' => count($destination),
+			'list' => $destination
+		]);
+	}
+
+	/**
+	 * count email forwarders for a given email address
+	 *
+	 * @param int $id
+	 *        	optional, the email-address-id
+	 * @param string $emailaddr
+	 *        	optional, the email-address to delete the forwarder from
+	 * @param int $customerid
+	 *        	optional, admin-only, the customer-id
+	 * @param string $loginname
+	 *        	optional, admin-only, the loginname
+	 *        	
+	 * @access admin,customer
+	 * @throws \Exception
+	 * @return string json-encoded array
+	 */
+	public function listingCount()
+	{
+		if ($this->isAdmin() == false && Settings::IsInList('panel.customer_hide_options', 'email')) {
+			throw new \Exception("You cannot access this resource", 405);
+		}
+
+		// parameter
+		$id = $this->getParam('id', true, 0);
+		$ea_optional = ($id <= 0 ? false : true);
+		$emailaddr = $this->getParam('emailaddr', $ea_optional, '');
+
+		// validation
+		$result = $this->apiCall('Emails.get', array(
+			'id' => $id,
+			'emailaddr' => $emailaddr
+		));
+		$id = $result['id'];
+
+		$result['destination'] = explode(' ', $result['destination']);
+
+		return $this->response(200, "successfull", count($result['destination']));
 	}
 
 	/**
